@@ -27,7 +27,7 @@
 
 #include <gtk/gtk.h>
 
-#include <parole/parole-file.h>
+#include "parole-file.h"
 
 G_BEGIN_DECLS
 
@@ -37,8 +37,12 @@ GtkFileFilter 		*parole_get_supported_video_filter	(void);
 
 GtkFileFilter 		*parole_get_supported_media_filter	(void);
 
+GtkRecentFilter     *parole_get_supported_recent_media_filter	(void);
+
 GtkFileFilter 		*parole_get_supported_files_filter	(void);
 
+GtkRecentFilter     *parole_get_supported_recent_files_filter (void);
+
 GtkFileFilter 		*parole_get_supported_playlist_filter	(void);
 
 gboolean		 parole_file_filter			(GtkFileFilter *filter,
