@@ -25,19 +25,19 @@
 
 #include <glib-object.h>
 
-#include <parole/parole-provider-plugin.h>
-#include <parole/parole-provider-player.h>
-#include <parole/parole-file.h>
-#include <parole/parole-stream.h>
-#include <parole/parole-pl-parser.h>
-#include <parole/parole-filters.h>
-#include <parole/parole-debug.h>
+#include <src/misc/parole-provider-plugin.h>
+#include <src/misc/parole-provider-player.h>
+#include <src/misc/parole-file.h>
+#include <src/misc/parole-stream.h>
+#include <src/misc/parole-pl-parser.h>
+#include <src/misc/parole-filters.h>
+#include <src/misc/parole-debug.h>
 
 #include <libxfce4util/libxfce4util.h>
 
 #define PAROLE_MAJOR_VERSION		0
-#define PAROLE_MINOR_VERSION		2
-#define PAROLE_MICRO_VERSION		0.5
+#define PAROLE_MINOR_VERSION		4
+#define PAROLE_MICRO_VERSION		0
 
 /**
  * PAROLE_CHECK_VERSION:
